# -------------------------------------------------------------------------------------------
#
# How to build for normal kernel
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-8.1.15.el5' xfs.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-8.1.15.el5' xfs.spec
#
# How to build for the running kernel:
#
#  rpmbuild -ba --target i686   xfs.spec
#  rpmbuild -ba --target x86_64 xfs.spec
#
# -------------------------------------------------------------------------------------------


%{?!kernel:%define kernel %(rpm -q kernel-devel | tail -1 | sed -e 's|kernel-devel-||')}

%define kversion %(echo "%{kernel}" | sed -e 's|-.*||')
%define krelease %(echo "%{kernel}" | sed -e 's|.*-||')

%define kernel_src_path /lib/modules/%{kernel}/build

%define kernel_moduledir /lib/modules/%{kernel}

%define pkg_name xfs
%define kmdl_name kernel-module-%{pkg_name}-%{kernel}

# -------------------------------------------------------------------------------------------

Summary: 	The XFS(tm) Filesystem from Silicon Graphics, Inc.
Name: 		%{pkg_name}-filesystem
Version: 	0.4
Release: 	1%{?dist}
Epoch: 		0
Packager: 	Urs Beyerle <urs.beyerle@psi.ch>
License: 	GPL
URL:            http://oss.sgi.com/projects/xfs
Group: 		System Environment/Kernel
Source0		: %{pkg_name}-kern.tar.gz
Source1		: config.xfs
# Allow the code to build as an out-of-tree module
Patch0		: xfs_ootbuild.patch

# Update patches from the sles9 kernel since first release
Patch1          : xfs-kern-202363a-fix-xfs_finish_reclaim_all-umount-deadlock
Patch2          : xfs-log-diag
Patch3          : xfs-kern-25238a-quota-trans-diag
Patch4          : xfs-ftruncate-stale-data
Patch5          : xfs-kern-930841-default_acl_enospc_fix
Patch6          : xfs-kern-25687a-sles9sp3-iunpin-reclaim-fix
Patch7          : xfs-kern-26040a-do-not-dirty-inode-being-freed
Patch8          : xfs-kern-26347a-fix-race-on-link

# This patchset is for making the xfs codebase in sles9 work
# with an RHEL4 kernel.
Patch100        : xfs-version.patch
Patch101        : xfs_qsort.patch
Patch102        : xfs_proc_args.patch
Patch103        : xfs_export_ops.patch
Patch104        : xfs_write_inode_return.patch
Patch105        : xfs_dmapi_address_space.patch
# Needed for kernels < 2.6.9-42.EL, uncomment below
Patch106        : xfs_direct_io_locking.patch

BuildRoot: 	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} )
Requires:       kernel-module-%{pkg_name} >= %{version}-%{release}

%description
The XFS(tm) Filesystem from Silicon Graphics, Inc.
XFS is a highly scalable, high-performance journaling filesystem that provides 
rapid recovery from system crashes.

Kernel modules for %{name} are in kernel-module-%{pkg_name} rpms.

%package -n 	%{kmdl_name}
Summary:        Kernel modules for %{name}.
Group:          System Environment/Kernel
License:        GPL
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
# Requires:       %{pkg_name}

%description -n %{kmdl_name}
Kernel modules for %{name}.

The XFS(tm) Filesystem from Silicon Graphics, Inc.
XFS is a highly scalable, high-performance journaling filesystem that provides 
rapid recovery from system crashes.


%prep
%setup -q -c -T -a 0
pushd %{pkg_name}
cp %{SOURCE1} .
%patch0 -p1

%patch1 -p3
%patch2 -p3
%patch3 -p3
%patch4 -p3
%patch5 -p3
%patch6 -p3
%patch7 -p3
%patch8 -p3

%patch100 -p1
%patch101 -p1
%patch102 -p1
%patch103 -p1
%patch104 -p1
%patch105 -p1
#%%patch106 -p1

echo "#define XFS_VERSION_STRING \"SGI XFS from %{name}-%{version}-%{release} rpm\"" > linux-2.6/xfs_module_version.h


%define 	kernel_module_dir	kernel/fs/xfs

%build
echo -e "\nDriver version: %{version}\nKernel version: %{kernel}\n"
cd %{pkg_name}

make TOPDIR=%{kernel_src_path} clean
make TOPDIR=%{kernel_src_path} modules

INST_MODLIB=${RPM_BUILD_ROOT}/lib/modules/%{kernel}/%{kernel_module_dir}
mkdir -p ${INST_MODLIB}
cp *.ko ${INST_MODLIB}/


%install
echo

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%postun -n %{kmdl_name}
depmod -a %{kernel} >/dev/null 2>&1 || :	

%post -n %{kmdl_name}
depmod -a %{kernel} >/dev/null 2>&1 || :

%files 
%defattr(-,root,root,-)

%files -n %{kmdl_name}
%defattr(744,root,root,-)
/lib/modules/%{kernel}/%{kernel_module_dir}

%changelog
* Fri Dec 12 2008 Troy Dawson  <dawson@fnal.gov> 0.4-1
- Changed the name to xfs-filesystem to avoid confusion with xfs

* Tue Mar 18 2008 Troy Dawson  <dawson@fnal.gov> 0.4-1
- Modified this to do kernel-modules instead of kmod
- spec template taken from Urs Beyerle's xfs for sl5

* Tue May 22 2007 Johnny Hughes  <johnny@centos.org> 0.4-1
- Modified this version of the spec to work with el4.

* Thu Apr 19 2007 Johnny Hughes <johnny@centos.org> 0.3-2
- Modified kmodtool (Source10) to remove the requirement for xfs-kmod-common
 
* Tue Apr 17 2007 Johnny Hughes <johnny@centos.org>
- Initial use in CentOS-5
- Added paevar and modified paevar, smpvar, xenvar, xdumpvar to follow
  EL5 and not FC6 naming conventions.

